@@ -60,7 +60,8 @@ GType            yelp_window_get_type        (void);
 GtkWidget *      yelp_window_new             (GNode         *doc_tree,
 					      GList         *index);
 void             yelp_window_load            (YelpWindow    *window,
-					      gchar         *uri);
+					      const gchar   *uri);
 YelpDocInfo *    yelp_window_get_doc_info    (YelpWindow    *window);
+GtkUIManager *   yelp_window_get_ui_manager  (YelpWindow    *window);
 
 #endif /* __YELP_WINDOW_H__ */
